/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.util.Map;

import com.ibm.ram.common.data.*;
import com.ibm.ram.internal.client.util.AssetConstants;


/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class ArtifactRule extends AbstractRule {

	static final String ARTIFACT_NAME_KEY = "artifactName"; //$NON-NLS-1$
	static final String ARTIFACT_URL_KEY = "artifactUrl"; //$NON-NLS-1$
	static final String ARTIFACT_LABEL_KEY = "artifactLabel"; //$NON-NLS-1$
	public static final String ID = ArtifactRule.class.getName();
	
	private String name;
	private String url;
	private String label;
	
	public boolean applyValue(Asset asset) {
		if (name != null && name.length() > 0 && url != null && url.length() > 0) {
			addUrlArtifact(asset); 
			return true;
		}
		return false;
	}
	
	public void initialize(Map config) {
		super.initialize(config);
		setArtifactName((String)config.get(ARTIFACT_NAME_KEY));
		setArtifactUrl((String)config.get(ARTIFACT_URL_KEY));
		setArtifactLabel((String)config.get(ARTIFACT_LABEL_KEY));
	}

	public void save(Map config) {
		super.save(config);
		config.put(ARTIFACT_NAME_KEY, name);
		config.put(ARTIFACT_URL_KEY, url);
		config.put(ARTIFACT_LABEL_KEY, label);
	}
	
	public String getArtifactLabel() {
		return label;
	}
	
	public void setArtifactLabel(String label) {
		this.label = label;
	}
	
	private FolderArtifact getArtifactsRoot(Asset asset) {
		FolderArtifact root = asset.getArtifactsRoot();
		if (root == null) {
			root = new FolderArtifact();
			asset.setArtifactsRoot(root);
		}
		return root;
	}
	
	private void addArtifact(Asset asset, Artifact artifact) {
		FolderArtifact root = getArtifactsRoot(asset);
		Artifact[] oldArtifacts = root.getChildren();
		if (oldArtifacts == null)
			oldArtifacts = new Artifact[0];
		Artifact[] newArtifacts = new Artifact[oldArtifacts.length + 1];
		System.arraycopy(oldArtifacts, 0, newArtifacts, 0, oldArtifacts.length);
		newArtifacts[newArtifacts.length - 1] = artifact;
		root.setChildren(newArtifacts);
	}
	
	private void addUrlArtifact(Asset asset) {
		URLArtifact artifact = new URLArtifact();
		// for now, we will set the name to the url
		artifact.setName(name);
		artifact.setURL(url);
		artifact.setPath(AssetConstants.FILE_DELIM);
		addArtifact(asset, artifact);
	}
	
	public String getId() {
		return ID;
	}
	
	public void setArtifactName(String name) {
		this.name = name;
	}
	
	public void setArtifactUrl(String url) {
		this.url = url;
	}

}
