/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.util.*;

import com.ibm.ram.common.data.Asset;
import com.ibm.ram.common.data.AssetAttribute;


/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class AttributeRule extends AbstractRule {

	static final String ATTRIBUTE_NAME = "attributeName"; //$NON-NLS-1$
	static final String ATTRIBUTE_VALUE = "attributeValue"; //$NON-NLS-1$
	public static final String ID = AttributeRule.class.getName();
	
	private String attributeName;
	private String attributeValue;
	
	public void initialize(Map config) {
		super.initialize(config);
		setAttributeName((String)config.get(ATTRIBUTE_NAME));
		setAttributeValue((String)config.get(ATTRIBUTE_VALUE));
	}

	public void save(Map config) {
		super.save(config);
		config.put(ATTRIBUTE_NAME, attributeName);
		config.put(ATTRIBUTE_VALUE, attributeValue);
	}
	
	public boolean applyValue(Asset asset) {
		if (attributeName != null && attributeName.length() > 0 && attributeValue != null && attributeValue.length() > 0) {
			AssetAttribute attribute = asset.getAssetAttribute(attributeName);
			if (attribute == null) {
				attribute = new AssetAttribute();
				attribute.setName(attributeName);
				AssetAttribute[] oldAttributes = asset.getAssetAttributes();
				if (oldAttributes == null)
					oldAttributes = new AssetAttribute[0];
				AssetAttribute[] newAttributes = new AssetAttribute[oldAttributes.length + 1];
				System.arraycopy(oldAttributes, 0, newAttributes, 0, oldAttributes.length);
				newAttributes[newAttributes.length - 1] = attribute;
				asset.setAssetAttributes(newAttributes);
			}
			attribute.setValues(new String[] {attributeValue});
			return true;
		}
		return false;
	}
	
	public void setAttributeName(String name) {
		this.attributeName = name;
	}
	
	public void setAttributeValue(String value) {
		this.attributeValue = value;
	}
	
	public String getId() {
		return ID;
	}

}
