/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.io.File;

import org.apache.tools.ant.DirectoryScanner;
import org.eclipse.core.runtime.IProgressMonitor;

import com.ibm.ram.client.LocalFileArtifact;
import com.ibm.ram.client.LocalFolderArtifact;
import com.ibm.ram.common.data.*;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class FolderRuleDelegate extends AbstractRuleDelegate {

	private static final String MANIFEST_FILE_NAME = "manifest.rmd"; //$NON-NLS-1$

	public Asset apply(Object object, IRule rule, IProgressMonitor monitor) {
		if (rule instanceof AssetRule) {
			File folder = (File)object;
			File manifestFile = new File(folder, MANIFEST_FILE_NAME);
			Asset asset = new Asset();
			if (manifestFile != null && manifestFile.exists())
				ManifestUtil.processManifest(manifestFile, asset);
			else
				asset.setName(folder.getName());
			return asset;
		}
		return null;
	}

	public void apply(Object object, Asset asset, IRule rule, IProgressMonitor monitor) {
		if (rule instanceof ArtifactRule) {
			File folder = (File)object;
			addFolderArtifact(getArtifactsRoot(asset), folder);
		} else if (rule instanceof AssetRule) {
			File folder = (File)object;
			File manifestFile = new File(folder, MANIFEST_FILE_NAME);
			if (manifestFile != null && manifestFile.exists())
				ManifestUtil.processManifest(manifestFile, asset);
			else
				asset.setName(folder.getName());
		} else if (rule instanceof CommunityRule) {
			File folder = (File)object;
			setCommunity(folder, asset, monitor);
		}
	}

	private void setCommunity(File folder, Asset asset, IProgressMonitor monitor) {
		if (folder != null && folder.exists()) {
			CommunityInformation community = new CommunityInformation();
			community.setName(folder.getName());
			asset.setCommunity(community);
		}
	}

	public boolean canHandle(Object obj, IRule rule) {
		return obj instanceof File && ((File)obj).isDirectory();
	}

	public Object[] filter(Object parent, String filter) {
		if (parent instanceof File) {
			File parentFile = (File)parent;
			if (parentFile.isDirectory()) {
				if (filter == null || filter.length() == 0)
					return parentFile.listFiles();
				DirectoryScanner scanner = new DirectoryScanner();
				if (filter != null && filter.length() > 0)
					scanner.setIncludes(new String[] {filter});
				scanner.setBasedir(parentFile);
				scanner.scan();
				String[] filePaths = scanner.getIncludedFiles();
				String[] dirPaths = scanner.getIncludedDirectories();
				File[] files = new File[filePaths.length + dirPaths.length];
				for (int i = 0; i <  filePaths.length; i++)
					files[i] = new File(parentFile, filePaths[i]);
				for (int i = 0; i <  dirPaths.length; i++)
					files[i + filePaths.length] = new File(parentFile, dirPaths[i]);
				return files;
			} else {
				
			}
		}
		return null;
	}
	
	private FolderArtifact getArtifactsRoot(Asset asset) {
		FolderArtifact root = asset.getArtifactsRoot();
		if (root == null) {
			root = new FolderArtifact();
			asset.setArtifactsRoot(root);
		}
		return root;
	}
	
	private void addArtifact(FolderArtifact parent, Artifact artifact) {
		Artifact[] oldArtifacts = parent.getChildren();
		if (oldArtifacts == null)
			oldArtifacts = new Artifact[0];
		Artifact[] newArtifacts = new Artifact[oldArtifacts.length + 1];
		System.arraycopy(oldArtifacts, 0, newArtifacts, 0, oldArtifacts.length);
		newArtifacts[newArtifacts.length - 1] = artifact;
		parent.setChildren(newArtifacts);
	}
	
	private void addFolderArtifact(FolderArtifact parent, File folder) {
		Artifact[] artifacts = parent.getChildren();
		FolderArtifact folderArtifact = null;
		if (artifacts != null) {
			for (int i = 0; i < artifacts.length; i++) {
				if (artifacts[i].getName().equals(folder.getName()) && artifacts[i] instanceof FolderArtifact) {
					folderArtifact = (FolderArtifact)artifacts[i];
					break;
				}
			}
		}
		if (folderArtifact == null) {
			LocalFolderArtifact artifact = new LocalFolderArtifact(folder);
			addArtifact(parent, artifact);
		} else {
			// a folder with this name already exists so do a deep copy to make sure there aren't duplicate artifacts
			addFileArtifacts(folderArtifact, folder);
		}
	}
	
	private void addFileArtifacts(FolderArtifact folderArtifact, File folder) {
		File[] files = folder.listFiles();
		for (int i = 0; i < files.length; i++) {
			if (files[i].isDirectory())
				addFolderArtifact(folderArtifact, files[i]);
			else if (files[i].isFile()) {
				addFileArtifact(folderArtifact, files[i]);
			}
		}
	}
	
	private void addFileArtifact(FolderArtifact parent, File file) {
		Artifact[] artifacts = parent.getChildren();
		if (artifacts != null) {
			for (int i = 0; i < artifacts.length; i++) {
				if (artifacts[i].getName().equals(file.getName()))
					return;
			}
		}
		LocalFileArtifact artifact = new LocalFileArtifact(file);
		addArtifact(parent, artifact);
	}
	
}
