/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import org.eclipse.core.runtime.IProgressMonitor;

import com.ibm.ram.common.data.Asset;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public interface IRuleDelegate {

	/**
	 * Apply the rule to the given object. If assets are created by, return the list of assets.
	 * 
	 * @param object the object used to apply this rule
	 * @param rule the rule to apply
	 * @return an asset created by this rule, or null if no asset was created
	 */
	Asset apply(Object obj, IRule rule, IProgressMonitor monitor);
	
	/**
	 * Apply the rule to the given object. An asset has already been created and passed in as a parameter.
	 * 
	 * @param object the object used to apply the rule
	 * @param asset the asset
	 * @param rule the rule to apply
	 */
	void apply(Object obj, Asset asset, IRule rule, IProgressMonitor monitor);
	
	/**
	 * @return true if this delegate can handle applying the rule to the object.
	 */
	boolean canHandle(Object obj, IRule rule);
	
	/**
	 * Returns the priority of this delegate. If more than one delegate can handle a particular
	 * object/rule combination, then the one with the highest priority will be the one to 
	 * handle it.
	 * 
	 * @return the priority of this delegate
	 */
	int getPriority();
	
	/**
	 * Sets the priority of this delegate. If more than one delegate can handle a particular
	 * object/rule combination, then the one with the highest priority will be the one to 
	 * handle it.
	 * 
	 * param priority the priority of this delegate
	 */
	void setPriority(int priority);
	
	Object[] filter(Object parent, String filter);
	
}
