/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.util.Map;

import com.ibm.ram.common.data.Asset;
import com.ibm.ram.common.data.UserInformation;


/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class OwnerRule extends AbstractRule {

	static final String OWNER = "owner"; //$NON-NLS-1$
	public static final String ID = OwnerRule.class.getName();
	
	private String userId;
	
	public void initialize(Map config) {
		super.initialize(config);
		setUserId((String)config.get(OWNER));
	}

	public void save(Map config) {
		super.save(config);
		config.put(OWNER, userId);
	}
	
	public boolean applyValue(Asset asset) {
		if (userId != null && userId.length() > 0) {
			addOwner(asset, userId);
			return true;
		}
		return false;
	}
	
	private void addOwner(Asset asset, String uid) {
		UserInformation[] oldOwners = asset.getOwners();
		if (oldOwners == null)
			oldOwners = new UserInformation[0];
		UserInformation[] newOwners = new UserInformation[oldOwners.length + 1];
		System.arraycopy(oldOwners, 0, newOwners, 0, oldOwners.length);
		UserInformation owner = new UserInformation();
		owner.setUid(uid);
		newOwners[newOwners.length - 1] = owner;
		asset.setOwners(newOwners);
	}

	public String getId() {
		return ID;
	}
	
	public void setUserId(String id) {
		this.userId = id;
	}

}
