/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.eclipse.core.runtime.*;

import com.ibm.ram.internal.rich.ui.UIExtensionPlugin;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class RuleDelegateExtensionManager {
	
	private static final Logger logger = Logger.getLogger(RuleDelegateExtensionManager.class.getName());

	private static final String RULE_DELEGATE_EXT_PT_ID = "batchRuleDelegate"; //$NON-NLS-1$
	private static final String RULE_DELEGATE_ATTR_CLASS = "class"; //$NON-NLS-1$
	private static final String RULE_DELEGATE_ATTR_PRIORITY = "priority"; //$NON-NLS-1$
	
	private static IRuleDelegate[] ruleDelegates;
	
	public static IRuleDelegate[] getDelegates() {
		if (ruleDelegates == null) {
			IConfigurationElement[] extensions = Platform.getExtensionRegistry().getConfigurationElementsFor(UIExtensionPlugin.getPluginId(), RULE_DELEGATE_EXT_PT_ID);
			List delegates = new ArrayList();
			for (int i = 0; i < extensions.length; i++) {
				IConfigurationElement extension = extensions[i];
				try {
					Object obj = extension.createExecutableExtension(RULE_DELEGATE_ATTR_CLASS);
					if (obj instanceof IRuleDelegate) {
						IRuleDelegate delegate = (IRuleDelegate)obj;
						String priorityStr = extension.getAttribute(RULE_DELEGATE_ATTR_PRIORITY);
						if (priorityStr != null) {
							try {
								delegate.setPriority(Integer.parseInt(priorityStr));
							} catch (NumberFormatException e) {
								logger.log(Level.SEVERE, null, e);
							}
						}
						delegates.add(delegate);
					}
				} catch (CoreException e) {
					logger.log(Level.SEVERE, null, e);
				}
			}
			ruleDelegates = (IRuleDelegate[])delegates.toArray(new IRuleDelegate[delegates.size()]);
		}
		return ruleDelegates;
	}
	
}
