/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.io.File;

import org.apache.tools.ant.DirectoryScanner;
import org.eclipse.core.runtime.IProgressMonitor;

import com.ibm.ram.common.data.Asset;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class ZipRuleDelegate extends AbstractRuleDelegate {

	private static final String MANIFEST_FILE_NAME = "manifest.rmd"; //$NON-NLS-1$

	public Asset apply(Object object, IRule rule, IProgressMonitor monitor) {
		if (rule instanceof AssetRule) {
			File file = (File)object;
			File manifest = null;
			File tempFolder = ZipUtil.extractZip(null, file, monitor);
			manifest = new File(tempFolder, MANIFEST_FILE_NAME);
			Asset asset = new Asset();
			if (manifest != null && manifest.exists()) {
				ManifestUtil.processManifest(manifest, asset);
			} else {
				String name = file.getName();
				int i = name.lastIndexOf('.');
				if (i > 1)
					name = name.substring(0, i);
				asset.setName(name);
			}
			return asset;
		}
		return null;
	}

	public void apply(Object obj, Asset asset, IRule rule, IProgressMonitor monitor) {
		
	}

	public boolean canHandle(Object obj, IRule rule) {
		return obj instanceof File && ZipUtil.getZipFile((File)obj) != null;
	}
	
	public Object[] filter(Object parent, String filter) {
		if (parent instanceof File) {
			File parentFile = (File)parent;
			if (ZipUtil.isSupportedZipFile(parentFile)) {
				parentFile = new File(System.getProperty("java.io.tmpdir"), parentFile.getName()); //$NON-NLS-1$
				if (parentFile.exists() && parentFile.isDirectory()) {
					if (filter == null || filter.length() == 0)
						return parentFile.listFiles();
					DirectoryScanner scanner = new DirectoryScanner();
					if (filter != null && filter.length() > 0)
						scanner.setIncludes(new String[] {filter});
					scanner.setBasedir(parentFile);
					scanner.scan();
					String[] filePaths = scanner.getIncludedFiles();
					String[] dirPaths = scanner.getIncludedDirectories();
					File[] files = new File[filePaths.length + dirPaths.length];
					for (int i = 0; i <  filePaths.length; i++)
						files[i] = new File(parentFile, filePaths[i]);
					for (int i = 0; i <  dirPaths.length; i++)
						files[i + filePaths.length] = new File(parentFile, dirPaths[i]);
					return files;
				}
			}
		}
		return null;
	}
	
}
