/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.zip.ZipException;

import org.eclipse.core.runtime.IProgressMonitor;

import com.ibm.ram.io.zip.ZipEntry;
import com.ibm.ram.io.zip.ZipFile;


public class ZipUtil {

	private static final String[] SUPPORTED_EXTENSIONS = new String[] {
		".zip", ".ras", ".war", ".ear", ".jar" //$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$//$NON-NLS-4$//$NON-NLS-5$
	};

	public static boolean isSupportedZipFile(File file) {
		String filename = file.getName();
		for (int i = 0; i < SUPPORTED_EXTENSIONS.length; i++) {
			if (filename.endsWith(SUPPORTED_EXTENSIONS[i]))
				return true;
		}
		return false;
	}
	
	public static ZipFile getZipFile(File file) {
		if (!isSupportedZipFile(file))
			return null;
		try {
			return new ZipFile(file);
		} catch (ZipException e) {
		} catch (IOException e) {
		}
		return null;
	}

	public static File extractZip(File destination, File file, IProgressMonitor monitor) {
		ZipFile zip = getZipFile(file);
		if (destination == null)
			destination = new File(System.getProperty("java.io.tmpdir"), file.getName()); //$NON-NLS-1$
		else
			destination = new File(destination, file.getName());
		Enumeration entries = zip.entries();
		while (entries.hasMoreElements() && !monitor.isCanceled()) {
			ZipEntry entry = (ZipEntry)entries.nextElement();
			File tmp = new File(destination, entry.getName());
			tmp.getParentFile().mkdirs();
			InputStream in = null;
			FileOutputStream out = null;
			try {
				in = zip.getInputStream(entry);
				out = new FileOutputStream(tmp);
				byte[] data = new byte[8192];
				int read;
				while ((read = in.read(data)) > -1 && !monitor.isCanceled()) {
					out.write(data, 0, read);
				}
			} catch (IOException e) {
			} finally {
				if (in != null) {
					try {
						in.close();
					} catch (IOException e) {}
				}
				if (out != null) {
					try {
						out.close();
					} catch (IOException e) {}
				}
			}
		}
		return destination;
	}
	
}
