/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Specify the metadata for an artifact rule.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class AssetRulePage extends RuleWizardPage {
	
	private Button allObjectsButton;
	private Button filteredObjectsButton;
	private AssetRule rule;
	private Text filterText;
	
	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public AssetRulePage(IRuleContainer ruleContainer) {
		super(ruleContainer, AssetRule.ID, Messages.Batch_FileSystem_Rule_AssetWizardPage_Title, null);
		setMessage(Messages.Batch_FileSystem_Rule_WizardPage_Description);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		allObjectsButton = new Button(composite, SWT.RADIO);
		allObjectsButton.setLayoutData(new GridData());
		allObjectsButton.setText(Messages.Batch_FileSystem_AssetRuleWizardPage_AllFilesButtonText);
		allObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		allObjectsButton.setSelection(true);
		
		filteredObjectsButton = new Button(composite, SWT.RADIO);
		filteredObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filteredObjectsButton.setText(Messages.Batch_FileSystem_AssetRuleWizardPage_FilteredFilesButtonText);

		Composite filterComposite = new Composite(composite, SWT.NONE);
		filterComposite.setLayout(new GridLayout(2, false));
		filterComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		final Label filterLabel = new Label(filterComposite, SWT.NONE);
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter + ":"); //$NON-NLS-1$
		filterLabel.setLayoutData(new GridData());
		filterLabel.setEnabled(false);
		
		filterText = new Text(filterComposite, SWT.BORDER);
		filterText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filterText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getRule().setFilter(text.getText());
				setPageComplete(canFinish());
			}
		});
		filterText.setEnabled(false);
		filteredObjectsButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				filterLabel.setEnabled(filteredObjectsButton.getSelection());
				filterText.setEnabled(filteredObjectsButton.getSelection());
				setPageComplete(canFinish());
			}
		});
		
		setControl(composite);
		setPageComplete(canFinish());
		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULEPAGE_ASSET);
	}
	
	public IRule getRule() {
		if (rule == null)
			rule = new AssetRule();
		return rule;
	}
	
	private boolean canFinish() {
		if (filteredObjectsButton != null && filteredObjectsButton.getSelection())
			return filterText.getText().length() > 0;
		return true;
	}
	
}
