/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.apache.log4j.Logger;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredViewer;
import org.eclipse.swt.dnd.DropTargetEvent;
import org.eclipse.swt.dnd.FileTransfer;
import org.eclipse.swt.dnd.TransferData;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.part.PluginDropAdapter;
import org.eclipse.ui.part.ResourceTransfer;
import org.eclipse.ui.views.navigator.LocalSelectionTransfer;

import com.ibm.ram.batch.ui.IBatchClientEditor;
import com.ibm.ram.internal.batch.filesystem.AssetRule;
import com.ibm.ram.internal.batch.filesystem.AssetTypeRule;
import com.ibm.ram.internal.batch.filesystem.CommunityRule;
import com.ibm.ram.internal.batch.filesystem.FileSystemDataSource;
import com.ibm.ram.internal.batch.filesystem.IRule;
import com.ibm.ram.internal.batch.filesystem.ShortDescriptionRule;
import com.ibm.ram.internal.batch.filesystem.VersionRule;
import com.ibm.ram.internal.rich.ui.util.Messages;
import com.ibm.ram.io.zip.ZipFile;

 

public class FileSystemDataSourceDropAdapter extends PluginDropAdapter {

	private static final Logger logger = Logger.getLogger(FileSystemDataSourceDropAdapter.class.getName());

	private static final String MANIFEST_FILE_NAME = "manifest.rmd"; //$NON-NLS-1$
	
	public FileSystemDataSourceDropAdapter(StructuredViewer viewer) {
		super(viewer);
		
		//5250 - Turn on the insertion feedback since you can drop any were on the source
		//and it figures out where to put it.
		setFeedbackEnabled(false);
	}
	
	

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.PluginDropAdapter#drop(org.eclipse.swt.dnd.DropTargetEvent)
	 */
	public void drop(DropTargetEvent event) {
		File[] files = null;
		TransferData currentTransfer = event.currentDataType;
		Object data = event.data;
	
		FileSystemDataSource root = getRoot(getCurrentTarget());
		//IRuleContainer droppedContainer = getDropedContainer(getCurrentTarget());
		
        if (LocalSelectionTransfer.getInstance().isSupportedType(
                currentTransfer)){
        	data = getSelectedResources();
        	IResource[] resources = (IResource[]) data;
            files = new File[resources.length];
            for(int i = 0; i < resources.length; i++){
            	files[i] = resources[i].getLocation().toFile();
            }
        }
        else if (ResourceTransfer.getInstance().isSupportedType(currentTransfer)) {
            IResource[] resources = (IResource[]) data;
            files = new File[resources.length];
            for(int i = 0; i < resources.length; i++){
            	files[i] = resources[i].getLocation().toFile();
            }
        } 

        else if (data instanceof String[]) {
        	String[] names = (String[]) data;
        	files = new File[names.length];
            for(int i = 0; i < names.length;i++){
            	files[i] = new File(names[i]);
            } 
        }
        
		IWorkbenchPage activePage = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
        IBatchClientEditor editor = (IBatchClientEditor)activePage.getActiveEditor();

        try {
        	Map roots = new HashMap();
        	
        	File selectedRootFile = new File(root.getRootPath());
        	roots.put(selectedRootFile, root);
        	
        	for(int i = 0; i < files.length; i++){
	        	//String path = files[i].getAbsolutePath();
	        	
	        	//need is Archive check?
	        	if(files[i].isDirectory() ||
	        			files[i].getPath().endsWith(".zip") || //$NON-NLS-1$
	        			files[i].getPath().endsWith(".jar") || //$NON-NLS-1$
	        			files[i].getPath().endsWith(".ras") || //$NON-NLS-1$
	        			files[i].getPath().endsWith(".war") || //$NON-NLS-1$
	        			files[i].getPath().endsWith(".ear")){ //$NON-NLS-1$
	        		
	        		File rootFile = null;
	        		File curFile = files[i];
	        		
	        		boolean hasManifest = false;
	        		
	        		ZipFile zip = null;
	        		try {
						if(files[i].isDirectory()){
							hasManifest = (new File(files[i], MANIFEST_FILE_NAME)).exists();
						}
						else{
							zip = new ZipFile(files[i]);
							hasManifest = zip.getEntry(MANIFEST_FILE_NAME) != null;
						}
					} catch (Exception e) {
						logger.warn(e.getLocalizedMessage(), e);
					}finally{
						if(zip != null){
							zip.close();
							zip = null;
						}
					}
	        		
	        		StringBuffer buffer = new StringBuffer(curFile.getName());
	        		curFile = curFile.getParentFile();
	        		while(curFile != null){
	        			if(!curFile.equals(selectedRootFile)){
	        				buffer.insert(0,curFile.getName() + File.separatorChar);
	        				curFile = curFile.getParentFile();
	        			}
	        			else{
	        				rootFile = selectedRootFile;
	        				break;
	        			}
	        		}
	        		
	        		//File was not found under the Data Source dropped on create a new one
	        		if(rootFile == null){	
	        			rootFile = files[i].getParentFile();
	        			buffer = new StringBuffer(files[i].getName());
	        		}
	        		FileSystemDataSource dataSource = (FileSystemDataSource)roots.get(rootFile);
	        		if(dataSource == null){
	        			dataSource = new FileSystemDataSource(rootFile.getAbsolutePath());
	        			
	        			editor.addBatchDataSource(dataSource);
	        			roots.put(rootFile, dataSource);
	        		}
	        		AssetRule assetRule = new AssetRule();
	        		assetRule.setFilter(buffer.toString());
	        		dataSource.add(assetRule);
	        		
//	        		//Artifact rules are no longer needed
//	        		//Add an artifact rule so that the artifacts are added
//	        		ArtifactRule artifactRule = new ArtifactRule();
//	        		assetRule.add(artifactRule);
	        		
	        		CommunityRule community = new CommunityRule();
	        		community.setCommunityName(Messages.FileSystemDataSourceDropAdapter_CommunityNotSet);
	        		assetRule.add(community);
	        		
	        		
	        		
	        		
	        		//Add some defaults if no manifest were found
	        		if(!hasManifest){
		        		AssetTypeRule assetType = new AssetTypeRule();
		        		assetType.setAssetTypeName(Messages.FileSystemDataSourceDropAdapter_AssetTypeNotSet);
		        		assetRule.add(assetType);
		        		
		        		VersionRule version = new VersionRule();
		        		version.setVersion(Messages.FileSystemDataSourceDropAdapter_Version);
		        		assetRule.add(version);
		        		
		        		ShortDescriptionRule shortDescription = new ShortDescriptionRule();
		        		shortDescription.setShortDescription(Messages.FileSystemDataSourceDropAdapter_UploadedViaBatchClient);
		        		assetRule.add(shortDescription);
	        		}
	        	}
	        }
        	
			editor.refresh();
		} catch (Exception e) {
			logger.error(Messages.RAMDataSourceViewerDropAdapter_ASSET_DROP_FAILED, e);
		}
		
	}
	
	private FileSystemDataSource getRoot(Object target){
		FileSystemDataSource ret = null;
		if(target instanceof FileSystemDataSource){
			ret = (FileSystemDataSource)target;
		}
		else if(target instanceof IRule){
			ret = (FileSystemDataSource)((IRule)target).getRoot();
		}
		return ret;
	}
	
//	private IRuleContainer getDropedContainer(Object target){
//		IRuleContainer ret = null;
//		if(target instanceof IRuleContainer){
//			ret = ((IRuleContainer)target);
//		}
//		else if(target instanceof IRule){
//			ret = ((IRule)target).getParent();
//		}
//		return ret;
//	}

	 /**
     * Returns the resource selection from the LocalSelectionTransfer.
     * 
     * @return the resource selection from the LocalSelectionTransfer
     */
    private IResource[] getSelectedResources() {
        ArrayList selectedResources = new ArrayList();

        ISelection selection = LocalSelectionTransfer.getInstance()
                .getSelection();
        if (selection instanceof IStructuredSelection) {
            IStructuredSelection ssel = (IStructuredSelection) selection;
            for (Iterator i = ssel.iterator(); i.hasNext();) {
                Object o = i.next();
                if (o instanceof IResource) {
                    selectedResources.add(o);
                }
                else if (o instanceof IAdaptable) {
                    IAdaptable a = (IAdaptable) o;
                    IResource r = (IResource) a.getAdapter(IResource.class);
                    if (r != null) {
                        selectedResources.add(r);
                    }
                }
            }
        }
        return (IResource[]) selectedResources.toArray(new IResource[selectedResources.size()]);
    }

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.part.PluginDropAdapter#validateDrop(java.lang.Object,
	 *      int, org.eclipse.swt.dnd.TransferData)
	 */
	public boolean validateDrop(Object target, int operation, TransferData transferType) {
		return LocalSelectionTransfer.getInstance().isSupportedType(transferType) ||  
			ResourceTransfer.getInstance().isSupportedType(transferType) ||
			FileTransfer.getInstance().isSupportedType(transferType);
		
	}
}
